@@ -9,25 +9,26 @@
    This file is part of the GNUstep GUI Library.
 
    This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
+   modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public
+   You should have received a copy of the GNU Lesser General Public
    License along with this library; see the file COPYING.LIB.
-   If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   If not, see <http://www.gnu.org/licenses/> or write to the 
+   Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _GNUstep_H_GSHorizontalTypesetter
 #define _GNUstep_H_GSHorizontalTypesetter
 
-#include <GNUstepGUI/GSTypesetter.h>
+#import <GNUstepGUI/GSTypesetter.h>
 
 @class NSLock;
 @class GSLayoutManager, NSTextContainer, NSTextStorage;
@@ -63,6 +64,11 @@
   NSRange fontRange; /* glyphs */
 
   struct GSHorizontalTypesetter_glyph_cache_s *cache;
+  /*
+    cache_base: index of first glyph in cache within the text container
+    cache_size: capacity of cache
+    cache_length: how much of the cache is filled
+   */
   unsigned int cache_base, cache_size, cache_length;
   BOOL at_end;
 
