@@ -133,7 +133,7 @@
       <p>
 	While many themes can be created without subclassing GSTheme,
 	there are some cases where writing code is necessary (most
-	notably when interfacing to a native themeing engine for some
+	notably when interfacing to a native theming engine for some
 	platform in order to make a GNUstep app have a native look).<br />
 	In these cases the subclass should follow certain rules in order
 	to operate cleanly and efficiently:
@@ -160,17 +160,17 @@
 	  with versions stored in the theme bundle.<br />
 	  If a subclass wishes to dynamically provide these resources rather
 	  than supplying them as static information in the bundle, it may
-	  update the in-memory information after the normal opertation has
+	  update the in-memory information after the normal operation has
 	  taken place.  This should be done by the theme registering itsself
 	  as an observer of GSThemeWillActivateNotification and adding the
-	  resources just before the theme bocomes active.<br />
+	  resources just before the theme becomes active.<br />
 	  Cleanup may be done in response to a GSThemeWillDeactivateNotification
 	  (called before the default cleanup) or a
 	  GSThemeDidDeactivateNotification (called after the default cleanup).
 	</desc>
         <term>Versioning</term>
 	<desc>
-	  With a theme which contains opnly static resources, versioning is
+	  With a theme which contains only static resources, versioning is
 	  not much of an issue, but with a code-based theme (ie where you
 	  subclass GSTheme) versioning does become very important.  This is
 	  because, while you can load code from a bundle, you can't unload
@@ -204,7 +204,11 @@
 	  A theme subclass may override the -imageClass method to change the
 	  class used to load each image from the bundle ... thus allowing
 	  customisation of not just the images but also of the image
-	  behavior in the (very rare) cases where this is desirable.
+	  behavior in the (very rare) cases where this is desirable.<br />
+          Finally, a theme may provide application specific images which are
+          loaded <em>in preference to</em> named images from the application's
+          own bundle.  These images are simply stored in a subdirectory whose
+          name is the same as the application's bundleIdentifier.
 	</desc>
       </deflist>
     </section>
@@ -217,6 +221,7 @@
 
 #import <Foundation/NSObject.h>
 #import <Foundation/NSGeometry.h>
+#import <AppKit/NSBox.h>
 #import <AppKit/NSCell.h>
 // For gradient types
 #import <AppKit/NSButtonCell.h>
@@ -226,23 +231,32 @@
 #import <AppKit/NSScroller.h>
 // For segmented control style constants
 #import <AppKit/NSSegmentedControl.h>
+// For tab view type 
+#import <AppKit/NSTabView.h>
+#import <AppKit/NSPrintPanel.h>
+#import <AppKit/NSPageLayout.h>
 
 #if	OS_API_VERSION(GS_API_NONE,GS_API_NONE)
 @class NSArray;
 @class NSBundle;
+@class NSBrowserCell;
 @class NSDictionary;
-
 @class NSButton;
 @class NSColor;
 @class NSColorList;
 @class NSColorWell;
 @class NSImage;
 @class NSMenuItemCell;
+@class NSPopUpButtonCell;
 @class NSMenuView;
 @class NSProgressIndicator;
 @class NSTableHeaderCell;
 @class NSTabViewItem;
 @class GSDrawTiles;
+@class GSTitleView;
+
+APPKIT_EXPORT	NSString	*GSSwitch;
+APPKIT_EXPORT   NSString        *GSRadio;
 
 /* First, declare names used for obtaining colors and/or tiles for specific
  * controls and parts of controls.
@@ -274,20 +288,59 @@ APPKIT_EXPORT  NSString        *GSBrowserHeader;
  */
 APPKIT_EXPORT  NSString        *GSMenuHorizontalBackground;
 APPKIT_EXPORT  NSString        *GSMenuVerticalBackground;
+APPKIT_EXPORT  NSString        *GSMenuTitleBackground;
 APPKIT_EXPORT  NSString        *GSMenuHorizontalItem;
 APPKIT_EXPORT  NSString        *GSMenuVerticalItem;
+APPKIT_EXPORT  NSString        *GSMenuSeparatorItem;
+
+/* NSPopUpButton parts */
+
+APPKIT_EXPORT  NSString        *GSPopUpButton;
 
 /*
  * Progress Indicator part names.
  */
+APPKIT_EXPORT  NSString        *GSProgressIndicatorBezel;
 APPKIT_EXPORT  NSString        *GSProgressIndicatorBarDeterminate;
 
 /*
  * Color well part names.
  */
 APPKIT_EXPORT  NSString        *GSColorWell;
+APPKIT_EXPORT  NSString        *GSColorWellInnerBorder;
 
+/* NSSliderCell parts */
+APPKIT_EXPORT  NSString        *GSSliderHorizontalTrack;
+APPKIT_EXPORT  NSString        *GSSliderVerticalTrack;
 
+/* NSBox parts */
+APPKIT_EXPORT  NSString        *GSBoxBorder;
+
+/* NSTabView parts */
+APPKIT_EXPORT  NSString        *GSTabViewSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBackgroundTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBottomSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBottomUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBottomBackgroundTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewLeftSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewLeftUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewLeftBackgroundTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewRightSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewRightUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewRightBackgroundTabFill;
+
+/**
+ * Structure to describe the size of top/bottom/left/right margins inside
+ * a button
+ */
+typedef struct GSThemeMargins
+{
+  CGFloat left;
+  CGFloat right;
+  CGFloat top;
+  CGFloat bottom;
+} GSThemeMargins;
 
 /**
  * This defines how the values in a tile array should be used when
@@ -328,8 +381,11 @@ GSThemeFillStyleFromString(NSString *s);
  */
 typedef enum {
   GSThemeNormalState = 0,	/** A control in its normal state */
+  GSThemeFirstResponderState,
   GSThemeDisabledState,		/** A control which is disabled */
+  GSThemeHighlightedFirstResponderState,
   GSThemeHighlightedState,	/** A control which is highlighted */
+  GSThemeSelectedFirstResponderState,
   GSThemeSelectedState		/** A control which is selected */
 } GSThemeControlState;
 
@@ -449,7 +505,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>This method is called automatically when the receiver is made into
  * the currently active theme by the +setTheme: method. Subclasses may
  * override it to perform startup operations, however, the method is not
- * really intended to be overridden, and subcasses should generally
+ * really intended to be overridden, and subclasses should generally
  * handle activation work in response to the GSThemeWillActivatenotification
  * posted by this method.
  * </p>
@@ -464,7 +520,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>Finally, this method marks all windows in the application as needing
  * update ... so they will draw themselves with the new theme information.
  * </p>
- * <p>NB. If a GSTheme subclass is integrating to an external native themeing
+ * <p>NB. If a GSTheme subclass is integrating to an external native theming
  * mechanism in order to make GNUstep apps look like native apps, then the
  * external theme may change dynamically and the GSTheme subclass may need
  * to change the GNUstep application to reflect this change.  When this
@@ -536,7 +592,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * sends a GSThemeDidDeactivateNotification to allow other parts of the
  * GUI library to update themselves.
  * </p>
- * <p>NB. If a GSTheme subclass is integrating to an external native themeing
+ * <p>NB. If a GSTheme subclass is integrating to an external native theming
  * mechanism in order to make GNUstep apps look like native apps, then the
  * external theme may change dynamically and the GSTheme subclass may need
  * to change the GNUstep application to reflect this change.  When this
@@ -591,14 +647,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  *     <deflist>
  *       <term>FileName</term>
  *       <desc>Name of the file (within the GSThemeTiles directory in the
- *       bundle) in which the image for this tile is tored.
+ *       bundle) in which the image for this tile is stored.
  *       </desc>
  *       <term>HorizontalDivision</term>
- *       <desc>The offet along the X-axis used to divide the image into
+ *       <desc>The offset along the X-axis used to divide the image into
  *       columns of tiles.
  *       </desc>
  *       <term>VerticalDivision</term>
- *       <desc>The offet along the Y-axis used to divide the image into
+ *       <desc>The offer along the Y-axis used to divide the image into
  *       rows of tiles.
  *       </desc>
  *     </deflist>
@@ -612,7 +668,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSString*) name;
 
-/** Returns the name used to locate theming resources for a particular gui
+/** Returns the name used to locate theming resources for a particular GUI
  * element.  If no name has been set for the particular object this method
  * returns nil.
  */
@@ -638,7 +694,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (void) setName: (NSString*)aString;
 
 /** Set the name that is used to identify theming resources for a particular
- * control or other gui element.  This is used so that where an element is
+ * control or other GUI element.  This is used so that where an element is
  * part of a control it can be displayed differently from the same class of
  * element used outside that control.<br />
  * Supplying a nil value for aString simply removes any name setting for
@@ -662,13 +718,13 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * and the authors of the theme.
  * </p>
  * <p>The code managing this object (if any) must be prepared to have the
- * content view of the window reparented into another window for display
+ * content view of the window re-parented into another window for display
  * on screen.
  * </p>
  */
 - (NSWindow*) themeInspector;
 
-/** Removes the name tile images from cahce, forcing re-creation next
+/** Removes the name tile images from cache, forcing re-creation next
  * time the named tiles are required.<br />
  * Passing nil for aName removes all named tiles.<br />
  * Passing a negative value for elementState applies to all caches.
@@ -688,7 +744,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * The elementState argument specifies the state for which tiles are
  * requested.
  * See the -colorNamed:state: method for determining colors to be
- * used for drawing specific gui elements.
+ * used for drawing specific GUI elements.
  */
 - (GSDrawTiles*) tilesNamed: (NSString*)aName
 		      state: (GSThemeControlState)elementState;
@@ -698,13 +754,18 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSString*) versionString;
 
+/**
+ * Return the theme's license.
+ */
+- (NSString*) license;
+
 @end
 
 /**
  * Theme drawing methods.<br />
  * Methods which return information/resources are generally expected
  * (ie unless explicitly documented otherwise) to be returning something
- * which persists until the mewthod is called again or until the current
+ * which persists until the method is called again or until the current
  * theme is deactivated (whichever comes first).<br />
  * This means that drawing code should <strong>not</strong> need to
  * retain/release any returned object (the theme is responsible for
@@ -719,6 +780,13 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 @interface	GSTheme (Drawing)
 
+/**
+ * Allows the theme to set an image or set attributes for drawing the
+ * button differently based on the key equivalent which is set.
+ */
+- (void) setKeyEquivalent: (NSString *)key 
+            forButtonCell: (NSButtonCell *)cell;
+
 /**
  * Draws a button frame and background (not its content) for the specified
  * cell and view.
@@ -732,9 +800,9 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 /**
  * Amount by which the button is inset by the border.
  */
-- (NSSize) buttonBorderForCell: (NSCell*)cell
-			 style: (int)style 
-                         state: (GSThemeControlState)state;
+- (GSThemeMargins) buttonMarginsForCell: (NSCell*)cell
+				  style: (int)style 
+				  state: (GSThemeControlState)state;
 
 /** 
  * Draws the indicator (normally a dotted rectangle) to show that
@@ -772,6 +840,23 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSSize) sizeForImageFrameStyle: (NSImageFrameStyle)frameStyle;
 
+/**
+ * Return YES if the scroller arrows are at the same end.
+ * Return NO to get one scroller arrow at each end of the scroller.
+ *
+ * The default implementation first checks the default GSScrollerArrowsSameEnd
+ * and if that is not set, delegates to the NSInterfaceStyle.
+ */
+- (BOOL) scrollerArrowsSameEndForScroller: (NSScroller *)aScroller;
+
+/**
+ * Returns YES if clicking in the scroller slot should scroll by one page,
+ * NO if the scroller should jump to the location clicked.
+ *
+ * The default implementation first checks the default GSScrollerScrollsByPage
+ * and if that is not set, delegates to the NSInterfaceStyle.
+ */
+- (BOOL) scrollerScrollsByPageForScroller: (NSScroller *)aScroller;
 
 /** 
  * Creates and returns the cell to be used to draw a scroller arrow of the
@@ -810,8 +895,25 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (float) defaultScrollerWidth;
 
+/**
+ * If YES, instructs NSScrollView to leave an empty square space where
+ * the horizontal and vertical scrollers meet.
+ * 
+ * Controlled by user default GSScrollViewUseBottomCorner; default YES.
+ */
+- (BOOL) scrollViewUseBottomCorner;
+
+/**
+ * If YES, instructs NSScrollView to make the scrollers overlap the border.
+ * The scroll view border is drawn using the NSScrollView part, which
+ * must be provided by the theme if this method returns YES.
+ * 
+ * Controlled by user default GSScrollViewScrollersOverlapBorders; default NO;
+ */
+- (BOOL) scrollViewScrollersOverlapBorders;
+
 /** 
- * Method fors toolbar theming.
+ * Method for toolbar theming.
  */
 - (NSColor *) toolbarBackgroundColor;
 - (NSColor *) toolbarBorderColor;
@@ -867,26 +969,180 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
                         roundedRight: (BOOL)roundedRight;
 
 /**
- * In some themes it may be necessary to override the drawing 
- * of an image a button cell and replace it with a rendered 
- * version (from the native theme).
+ * <p>Returns the color used to draw a menu view background.</p>
+ *
+ * <p>By default, looks up the color named <em>menuBackgroundColor</em>, 
+ * otherwise returns the window background color.</p>
+ *
+ * <p>The returned color is used by 
+ * -drawBackgroundForMenuView:withFrame:dirtyRect:horizontal:</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
  */
-- (void) drawImage: (NSImage *)image
-      inButtonCell: (NSButtonCell *) cell 
-	 withFrame: (NSRect) aRect
-          position: (NSPoint) position;
+- (NSColor *) menuBackgroundColor;
 
+/**
+ * <p>Returns the color used to draw a menu item background.</p>
+ *
+ * The menu item background is drawn atop the menu background.
+ *
+ * <p>By default, looks up the color named <em>menuItemBackgroundColor</em>, 
+ * otherwise returns the control background color.<br />
+ * When selected or highlighted, the background color is provided by 
+ * [NSColor+selectedMenuItemColor].</p>
+ *
+ * <p>The returned value used by 
+ * -drawBorderAndBackgroundForMenuItemCell:withFrame:inView:state:isHorizontal: 
+ * and [NSMenuItemCell-backgroundColor].</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
+ */
+- (NSColor *) menuItemBackgroundColor;
+- (NSColor *) menuBarBackgroundColor;
+- (NSColor *) menuBarBorderColor;
+
+/**
+ * <p>Returns the color used to draw a menu view border.</p>
+ *
+ * <p>By default, looks up the color named <em>menuBorderColor</em>, 
+ * otherwise returns the dark gray color.</p>
+ *
+ * <p>The returned color is used by 
+ * -drawBackgroundForMenuView:withFrame:dirtyRect:horizontal:</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
+ */
+- (NSColor *) menuBorderColor;
+
+/**
+ * <p>Returns a color to draw each edge in a menu view border.</p>
+ *
+ * <p>By default, returns -menuBorderColor for the upper and left edges of a  
+ * vertical menu, or for the bottom edge of a horizontal one.</p>
+ *
+ * <p>The returned edge color is used by 
+ * -drawBackgroundForMenuView:withFrame:dirtyRect:horizontal:</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
+ */
+- (NSColor *) menuBorderColorForEdge: (NSRectEdge)edge 
+                        isHorizontal: (BOOL)horizontal;
 - (void) drawBackgroundForMenuView: (NSMenuView*)menuView
                          withFrame: (NSRect)bounds
                          dirtyRect: (NSRect)dirtyRect
                         horizontal: (BOOL)horizontal;
-
+/**
+ * <p>Returns whether the menu item border should be drawn or not.</p>
+ *
+ * <p>By default, returns [NSMenuItemCell-isBordered] value. The value is NO 
+ * when the menu is horizontal, YES when vertical.</p>
+ *
+ * <p>The returned value used by 
+ * -drawBorderAndBackgroundForMenuItemCell:withFrame:inView:state:isHorizontal:</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
+ */
+- (BOOL) drawsBorderForMenuItemCell: (NSMenuItemCell *)cell 
+                              state: (GSThemeControlState)state
+                       isHorizontal: (BOOL)horizontal;
 // menu item cell drawing method
 - (void) drawBorderAndBackgroundForMenuItemCell: (NSMenuItemCell *)cell
                                       withFrame: (NSRect)cellFrame
                                          inView: (NSView *)controlView
                                           state: (GSThemeControlState)state
                                    isHorizontal: (BOOL)isHorizontal;
+
+/**
+ * <p>Draws the menu item title.</p>
+ *
+ * <p>Can be overridden to customize the text font, size and position.<br />
+ * You can use <code>[[cell menuItem] title]</code> to get the title.</p>
+ *
+ * <p>The title color is mapped to the theme state as described below:</p>
+ * <deflist>
+ * <term>GSThemeSelectedState</term>
+ * <desc>[NSColor+selectedMenuItemTextColor]</desc>
+ * <term>GSThemeDisabledState</term>
+ * <desc>[NSColor+controlTextColor] or 
+ * [NSColor+disabledControlTextColor]</desc>
+ * </deflist>
+ */
+- (void) drawTitleForMenuItemCell: (NSMenuItemCell *)cell
+                        withFrame: (NSRect)cellFrame
+                           inView: (NSView *)controlView
+                            state: (GSThemeControlState)state
+                     isHorizontal: (BOOL)isHorizontal;
+/**
+ * <p>Returns the color used to draw a separator line in a menu.</p>
+ *
+ * <p>By default, looks up the color named <em>menuSeparatorColor</em>, 
+ * otherwise returns nil.</p>
+ *
+ * <p>The returned color is used by 
+ * -drawSeparatorItemForMenuItemCell:withFrame:inView:isHorizontal:</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
+ */
+- (NSColor *) menuSeparatorColor;
+
+/**
+ * <p>Returns the left and right inset used to draw a separator line in a
+ * menu.</p>
+ *
+ * <p>By default, returns 3.0.</p>
+ *
+ * <p>The returned color is used by 
+ * -drawSeparatorItemForMenuItemCell:withFrame:inView:isHorizontal:</p>
+ * 
+ * <p>Can be overridden in subclasses to return a custom color, but generally
+ * should not.  Instead themes should provide default colors in the
+ * GSThemeDomain (in their Info.plist).</p>
+ */
+- (CGFloat) menuSeparatorInset;
+
+/**
+ * Amount that submenus overlap their parent menu by, horizontally.
+ * (i.e. applies to vertical menus)
+ *
+ * Controlled by GSMenuSubmenuHorizontalOverlap default
+ */
+- (CGFloat) menuSubmenuHorizontalOverlap;
+
+/**
+ * Amount that submenus overlap the horizontal menu bar by, vertically.
+ *
+ * Controlled by GSMenuSubmenuVerticalOverlap default
+ */
+- (CGFloat) menuSubmenuVerticalOverlap;
+
+/**
+ * <p>Draws a separator between normal menu items in a menu.</p>
+ *
+ * <p>Each separator corresponds to a menu item that returns YES to 
+ * -isSeparatorItem</p>
+ *
+ * <p>You can provide an image tile named <em>GSMenuSeparatorItem</em> to 
+ * draw the separator.<br />
+ * Can be overridden in subclasses to customize the drawing.</p>
+ *
+ * <p>See also -menuSeparatorColor and -menuSeparatorInset</p>
+ */
+- (void) drawSeparatorItemForMenuItemCell: (NSMenuItemCell *)cell
+                                withFrame: (NSRect)cellFrame
+                                   inView: (NSView *)controlView
+                             isHorizontal: (BOOL)isHorizontal;
 /**
  * Returns the class used to create the title bar in the given menu view.
  *
@@ -895,6 +1151,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (Class) titleViewClassForMenuView: (NSMenuView *)aMenuView;
 
+- (NSRect) drawMenuTitleBackground: (GSTitleView *)aTitleView
+			withBounds: (NSRect)bounds
+			  withClip: (NSRect)clipRect;
+
+- (CGFloat) menuBarHeight;
+- (CGFloat) menuItemHeight;
+- (CGFloat) menuSeparatorHeight;
+
 // NSColorWell drawing method
 - (NSRect) drawColorWellBorder: (NSColorWell*)well
                     withBounds: (NSRect)bounds
@@ -911,6 +1175,8 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (void) drawProgressIndicatorBarDeterminate: (NSRect)bounds;
 
 // Table drawing methods
+- (NSColor *) tableHeaderTextColorForState: (GSThemeControlState)state;
+
 - (void) drawTableCornerView: (NSView*)cornerView
                     withClip: (NSRect)aRect;
 - (void) drawTableHeaderCell: (NSTableHeaderCell *)cell
@@ -922,12 +1188,22 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 
 - (float) resizebarHeight;
 
+- (float) titlebarButtonSize;
+
+- (float) titlebarPaddingRight;
+
+- (float) titlebarPaddingTop;
+
+- (float) titlebarPaddingLeft;
+
 - (void) drawWindowBorder: (NSRect)rect
                 withFrame: (NSRect)frame 
              forStyleMask: (unsigned int)styleMask
                     state: (int)inputState
                  andTitle: (NSString*)title;
 
+- (NSColor *) browserHeaderTextColor;
+
 - (void) drawBrowserHeaderCell: (NSTableHeaderCell*)cell
 		     withFrame: (NSRect)rect
 			inView: (NSView*)view;
@@ -935,6 +1211,10 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (NSRect) browserHeaderDrawingRectForCell: (NSTableHeaderCell*)cell
 				 withFrame: (NSRect)rect;
 
+- (NSRect) tabViewContentRectForBounds: (NSRect)aRect
+			   tabViewType: (NSTabViewType)type
+			       tabView: (NSTabView *)view;
+
 - (void) drawTabViewRect: (NSRect)rect
 		  inView: (NSView *)view
 	       withItems: (NSArray *)items
@@ -950,6 +1230,12 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 	withScrollerRect: (NSRect)scrollerRect
 	      columnSize: (NSSize)columnSize;
 
+- (CGFloat) browserColumnSeparation;
+
+- (CGFloat) browserVerticalPadding;
+
+- (BOOL) browserUseBezels;
+
 - (void) drawMenuRect: (NSRect)rect
 	       inView: (NSView *)view
 	 isHorizontal: (BOOL)horizontal
@@ -958,6 +1244,11 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (void) drawScrollViewRect: (NSRect)rect
 	             inView: (NSView *)view;
 
+- (void) drawSliderBorderAndBackground: (NSBorderType)aType
+				 frame: (NSRect)cellFrame
+				inCell: (NSCell *)cell
+			  isHorizontal: (BOOL)horizontal;
+
 - (void) drawBarInside: (NSRect)rect
 		inCell: (NSCell *)cell
 	       flipped: (BOOL)flipped;
@@ -987,9 +1278,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 					inView: (NSView *)view
 			      selectingColumns: (BOOL)selectingColumns;
 
-- (void) drawTableViewRow: (int)rowIndex 
+- (void) drawTableViewRow: (NSInteger)rowIndex 
 		 clipRect: (NSRect)clipRect
 		   inView: (NSView *)view;
+
+- (void) drawBoxInClipRect: (NSRect)clipRect
+		   boxType: (NSBoxType)boxType
+		borderType: (NSBorderType)borderType
+		    inView: (NSBox *)box;
 @end
 
 /**
@@ -1013,7 +1309,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 		       inRect: (NSRect)border 
 		     withClip: (NSRect)clip;
 
-/** Draw a grey bezel border */
+/** Draw a gray bezel border */
 - (NSRect) drawGrayBezel: (NSRect)border withClip: (NSRect)clip;
 
 /** Draw a groove border */
@@ -1028,7 +1324,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 @end
 
 /**
- * Low level drawiong methods ... themes may use these for drawing,
+ * Low level drawing methods ... themes may use these for drawing,
  * but should not normally override them.
  */
 @interface	GSTheme (LowLevelDrawing)
@@ -1089,6 +1385,9 @@ withRepeatedImage: (NSImage*)image
 	  withTiles: (GSDrawTiles*)tiles
 	 background: (NSColor*)color;
 
+- (NSRect) fillRect: (NSRect)rect
+	  withTiles: (GSDrawTiles*)tiles;
+
 /**
  * Method to tile the supplied image to fill the vertical rectangle.<br />
  * The rect argument is the rectangle to be filled.<br />
@@ -1170,5 +1469,81 @@ withRepeatedImage: (NSImage*)image
 - (Class) savePanelClass;
 @end
 
+// Panels which can be overridden by the theme...
+@interface GSPrintPanel : NSPrintPanel
+@end
+
+@interface GSPageLayout : NSPageLayout
+@end
+
+@interface GSTheme (PrintPanels)
+/**
+ * This method returns the print panel class needed by the
+ * native environment.
+ */
+- (Class) printPanelClass;
+
+/**
+ * This method returns the page layout class needed by the 
+ * native environment.
+ */
+- (Class) pageLayoutClass;
+@end
+
+@interface GSTheme (NSWindow)
+/**
+ * This method returns the standard window button for the
+ * given mask for the current theme.
+ */ 
+- (NSButton *) standardWindowButton: (NSWindowButton)button
+		       forStyleMask: (NSUInteger) mask;
+				  
+/** 
+ * This method does any additional setup after the default 
+ * cell is set.
+ */
+- (void) didSetDefaultButtonCell: (NSButtonCell *)aCell;
+@end
+					 
+@interface GSTheme (NSBrowserCell)
+/** 
+ * Draw editor in cell
+ */
+- (void) drawEditorForCell: (NSCell *)cell
+		 withFrame: (NSRect)cellFrame
+	       	    inView: (NSView *)view;
+
+/** 
+ * Draw attributed text in cell
+ */
+- (void) drawInCell: (NSCell *)cell
+     attributedText: (NSAttributedString *)stringValue
+	    inFrame: (NSRect)cellFrame;
+
+/** 
+ * Draw the interior of the browser cell
+ */
+- (void) drawBrowserInteriorWithFrame: (NSRect)cellFrame 
+			     withCell: (NSBrowserCell *)cell
+			       inView: (NSView *)controlView
+			    withImage: (NSImage *)theImage
+		       alternateImage: (NSImage *)alternateImage
+			isHighlighted: (BOOL)isHighlighted
+				state: (int)state
+			       isLeaf: (BOOL)isLeaf;
+
+/** 
+ * This method returns the branch image
+ */
+- (NSImage *) branchImage;
+
+/** 
+ * This method returns the highlighted version of 
+ * the branch image
+ */
+- (NSImage *) highlightedBranchImage;
+@end
+
+
 #endif /* OS_API_VERSION */
 #endif /* _GNUstep_H_GSTheme */
