@@ -48,6 +48,7 @@
 #import <AppKit/NSAccessibilityConstants.h>
 #import <AppKit/NSActionCell.h>
 #import <AppKit/NSAnimationContext.h>
+#import <AppKit/NSAppearance.h>
 #import <AppKit/NSApplication.h>
 #import <AppKit/NSAttributedString.h>
 #import <AppKit/NSBitmapImageRep.h>
@@ -58,6 +59,7 @@
 #import <AppKit/NSButtonCell.h>
 #import <AppKit/NSCachedImageRep.h>
 #import <AppKit/NSCell.h>
+#import <AppKit/NSCIImageRep.h>
 #import <AppKit/NSClipView.h>
 #import <AppKit/NSCollectionView.h>
 #import <AppKit/NSCollectionViewItem.h>
@@ -70,6 +72,7 @@
 #import <AppKit/NSControl.h>
 #import <AppKit/NSCursor.h>
 #import <AppKit/NSCustomImageRep.h>
+#import <AppKit/NSDataAsset.h>
 #import <AppKit/NSDataLink.h>
 #import <AppKit/NSDataLinkManager.h>
 #import <AppKit/NSDataLinkPanel.h>
@@ -97,6 +100,10 @@
 #import <AppKit/NSPanel.h>
 #import <AppKit/NSPasteboard.h>
 #import <AppKit/NSPasteboardItem.h>
+#import <AppKit/NSPDFInfo.h>
+#import <AppKit/NSPDFImageRep.h>
+#import <AppKit/NSPDFPanel.h>
+#import <AppKit/NSPICTImageRep.h>
 #import <AppKit/NSPopover.h>
 #import <AppKit/NSPopUpButton.h>
 #import <AppKit/NSPopUpButtonCell.h>
@@ -133,19 +140,30 @@
 #import <AppKit/NSAffineTransform.h>
 #import <AppKit/NSArrayController.h>
 #import <AppKit/NSBezierPath.h>
+#import <AppKit/NSButtonTouchBarItem.h>
+#import <AppKit/NSColorSampler.h>
 #import <AppKit/NSColorSpace.h>
 #import <AppKit/NSComboBox.h>
 #import <AppKit/NSComboBoxCell.h>
 #import <AppKit/NSController.h>
+#import <AppKit/NSCandidateListTouchBarItem.h>
+#import <AppKit/NSClickGestureRecognizer.h>
+#import <AppKit/NSColorPickerTouchBarItem.h>
+#import <AppKit/NSCustomTouchBarItem.h>
+#import <AppKit/NSDatePicker.h>
+#import <AppKit/NSDatePickerCell.h>
+#import <AppKit/NSDockTile.h>
 #import <AppKit/NSDocument.h>
 #import <AppKit/NSDocumentController.h>
 #import <AppKit/NSDrawer.h>
-#import <AppKit/NSFileWrapper.h>
+#import <AppKit/NSFileWrapperExtensions.h>
+#import <AppKit/NSFontCollection.h>
 #import <AppKit/NSFontDescriptor.h>
 #import <AppKit/NSGestureRecognizer.h>
 #import <AppKit/NSGlyphGenerator.h>
 #import <AppKit/NSGradient.h>
 #import <AppKit/NSGraphicsContext.h>
+#import <AppKit/NSGroupTouchBarItem.h>
 #import <AppKit/NSHelpManager.h>
 #import <AppKit/NSInputManager.h>
 #import <AppKit/NSInputServer.h>
@@ -154,26 +172,41 @@
 #import <AppKit/NSLayoutManager.h>
 #import <AppKit/NSLevelIndicator.h>
 #import <AppKit/NSLevelIndicatorCell.h>
+#import <AppKit/NSMagnificationGestureRecognizer.h>
 #import <AppKit/NSMovie.h>
 #import <AppKit/NSMovieView.h>
+#import <AppKit/NSPanGestureRecognizer.h>
 #import <AppKit/NSNib.h>
+#import <AppKit/NSNibControlConnector.h>
+#import <AppKit/NSNibOutletConnector.h>
 #import <AppKit/NSNibDeclarations.h>
 #import <AppKit/NSObjectController.h>
 #import <AppKit/NSOpenGL.h>
 #import <AppKit/NSOpenGLView.h>
 #import <AppKit/NSOutlineView.h>
 #import <AppKit/NSParagraphStyle.h>
+#import <AppKit/NSPickerTouchBarItem.h>
+#import <AppKit/NSPredicateEditor.h>
+#import <AppKit/NSPredicateEditorRowTemplate.h>
 #import <AppKit/NSProgressIndicator.h>
+#import <AppKit/NSPopoverTouchBarItem.h>
+#import <AppKit/NSPressGestureRecognizer.h>
+#import <AppKit/NSRuleEditor.h>
 #import <AppKit/NSRulerMarker.h>
 #import <AppKit/NSRulerView.h>
+#import <AppKit/NSRotationGestureRecognizer.h>
 #import <AppKit/NSSearchField.h>
 #import <AppKit/NSSearchFieldCell.h>
 #import <AppKit/NSSecureTextField.h>
 #import <AppKit/NSSegmentedCell.h>
 #import <AppKit/NSSegmentedControl.h>
 #import <AppKit/NSShadow.h>
+#import <AppKit/NSSharingServicePickerTouchBarItem.h>
+#import <AppKit/NSSliderTouchBarItem.h>
 #import <AppKit/NSSound.h>
+#import <AppKit/NSSpeechRecognizer.h>
 #import <AppKit/NSSpeechSynthesizer.h>
+#import <AppKit/NSStepperTouchBarItem.h>
 #import <AppKit/NSStepper.h>
 #import <AppKit/NSStepperCell.h>
 #import <AppKit/NSTableColumn.h>
@@ -189,6 +222,9 @@
 #import <AppKit/NSTextStorage.h>
 #import <AppKit/NSTextTable.h>
 #import <AppKit/NSTextView.h>
+#import <AppKit/NSTouch.h>
+#import <AppKit/NSTouchBar.h>
+#import <AppKit/NSTouchBarItem.h>
 #import <AppKit/NSTokenField.h>
 #import <AppKit/NSTokenFieldCell.h>
 #import <AppKit/NSToolbar.h>
