@@ -269,6 +269,10 @@ typedef NSUInteger NSControlSize;
 
 // Pattern colour
 - (NSImage*) patternImage;
+
+// Tooltip colours
++ (NSColor*) toolTipColor;
++ (NSColor*) toolTipTextColor;
 #endif
 
 @end
@@ -286,5 +290,12 @@ APPKIT_EXPORT NSString	*NSSystemColorsDidChangeNotification;
 @end
 #endif
 
+typedef struct CGColor *CGColorRef;
+@interface NSColor (GSQuartz)
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (CGColorRef)CGColor;
+#endif
+@end
+
 #endif // _GNUstep_H_NSColor
 
