@@ -3,7 +3,7 @@
 
    Load, manipulate and display images
 
-   Copyright (C) 1996, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1996-2016 Free Software Foundation, Inc.
 
    Written by:  Adam Fedor <fedor@colorado.edu>
    Date: Feb 1996
@@ -45,6 +45,24 @@
 @class NSColor;
 @class NSView;
 
+/* Named images */
+
+APPKIT_EXPORT NSString *NSImageNameMultipleDocuments;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSImageNameUserAccounts;
+APPKIT_EXPORT NSString *NSImageNamePreferencesGeneral;
+APPKIT_EXPORT NSString *NSImageNameAdvanced;
+APPKIT_EXPORT NSString *NSImageNameInfo;
+APPKIT_EXPORT NSString *NSImageNameFontPanel;
+APPKIT_EXPORT NSString *NSImageNameColorPanel;
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSImageNameTrashEmpty;
+APPKIT_EXPORT NSString *NSImageNameTrashFull;
+APPKIT_EXPORT NSString *NSImageNameCaution;
+#endif
+
 /** Defines how an NSImage is to be cached.  Possible values are:
  *  <list>
  *   <item>NSImageCacheDefault</item>
@@ -65,6 +83,45 @@ typedef enum {
   NSImageCacheNever
 } NSImageCacheMode;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+APPKIT_EXTERN NSString *const NSImageNameQuickLookTemplate;
+APPKIT_EXTERN NSString *const NSImageNameBluetoothTemplate;
+APPKIT_EXTERN NSString *const NSImageNameIChatTheaterTemplate;
+APPKIT_EXTERN NSString *const NSImageNameSlideshowTemplate;
+APPKIT_EXTERN NSString *const NSImageNameActionTemplate;
+APPKIT_EXTERN NSString *const NSImageNameSmartBadgeTemplate;
+APPKIT_EXTERN NSString *const NSImageNameIconViewTemplate;
+APPKIT_EXTERN NSString *const NSImageNameListViewTemplate;
+APPKIT_EXTERN NSString *const NSImageNameColumnViewTemplate;
+APPKIT_EXTERN NSString *const NSImageNameFlowViewTemplate;
+APPKIT_EXTERN NSString *const NSImageNamePathTemplate;
+APPKIT_EXTERN NSString *const NSImageNameInvalidDataFreestandingTemplate;
+APPKIT_EXTERN NSString *const NSImageNameLockLockedTemplate;
+APPKIT_EXTERN NSString *const NSImageNameLockUnlockedTemplate;
+APPKIT_EXTERN NSString *const NSImageNameGoRightTemplate;
+APPKIT_EXTERN NSString *const NSImageNameGoLeftTemplate;
+APPKIT_EXTERN NSString *const NSImageNameRightFacingTriangleTemplate;
+APPKIT_EXTERN NSString *const NSImageNameLeftFacingTriangleTemplate;
+APPKIT_EXTERN NSString *const NSImageNameAddTemplate;
+APPKIT_EXTERN NSString *const NSImageNameRemoveTemplate;
+APPKIT_EXTERN NSString *const NSImageNameRevealFreestandingTemplate;
+APPKIT_EXTERN NSString *const NSImageNameFollowLinkFreestandingTemplate;
+APPKIT_EXTERN NSString *const NSImageNameEnterFullScreenTemplate;
+APPKIT_EXTERN NSString *const NSImageNameExitFullScreenTemplate;
+APPKIT_EXTERN NSString *const NSImageNameStopProgressTemplate;
+APPKIT_EXTERN NSString *const NSImageNameStopProgressFreestandingTemplate;
+APPKIT_EXTERN NSString *const NSImageNameRefreshTemplate;
+APPKIT_EXTERN NSString *const NSImageNameRefreshFreestandingTemplate;
+APPKIT_EXTERN NSString *const NSImageNameBonjour;
+APPKIT_EXTERN NSString *const NSImageNameComputer;
+APPKIT_EXTERN NSString *const NSImageNameFolderBurnable;
+APPKIT_EXTERN NSString *const NSImageNameFolderSmart;
+APPKIT_EXTERN NSString *const NSImageNameNetwork;
+#endif
+ 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+APPKIT_EXTERN NSString *const NSImageNameFolder;
+#endif
 
 @interface NSImage : NSObject <NSCoding, NSCopying>
 {
@@ -364,6 +421,16 @@ typedef enum {
 
 #endif
 
+/**
+ * <p>Draws the entire image in <code>rect</code> scaling if needed.<br>
+ * Drawing is done using <code>NSCompositeSourceOver</code>.
+ * </p>
+ */
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (void) drawInRect: (NSRect)rect;
+#endif
+
 //
 // Determining How the Image is Drawn 
 //
@@ -418,6 +485,13 @@ typedef enum {
 
 @end
 
+@interface NSImage (GSQuartz)
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (CGImageRef)CGImageForProposedRect: (NSRect *)proposedDestRect 
+                         context: (NSGraphicsContext *)referenceContext 
+                           hints: (NSDictionary *)hints;
+#endif
+@end
 
 @interface NSBundle (NSImageAdditions)
 
