@@ -29,18 +29,18 @@
 #define _GNUstep_H_NSInputManager
 #import <GNUstepBase/GSVersionMacros.h>
 
-#include <objc/Protocol.h>
-#include <objc/objc.h>
-#include <Foundation/NSGeometry.h>
-#include <Foundation/NSArray.h>
-#include <Foundation/NSAttributedString.h>
+#import <Foundation/NSGeometry.h>
+#import <Foundation/NSObject.h>
 
+@class NSArray;
+@class NSAttributedString;
+@class NSMutableArray;
 @class NSInputServer;
 @class NSEvent;
 @class NSImage;
 
 @protocol NSTextInput
-- (void) setMarkedText: (id)aString  selectedRange: (NSRange)selRange;
+- (void) setMarkedText: (id)aString selectedRange: (NSRange)selRange;
 - (BOOL) hasMarkedText;
 - (NSRange) markedRange;
 - (NSRange) selectedRange;
@@ -49,8 +49,8 @@
 
 
 - (NSAttributedString *) attributedSubstringFromRange: (NSRange)theRange;
-- (unsigned int) characterIndexForPoint: (NSPoint)thePoint;
-- (long) conversationIdentifier;
+- (NSUInteger) characterIndexForPoint: (NSPoint)thePoint;
+- (NSInteger) conversationIdentifier;
 - (void) doCommandBySelector: (SEL)aSelector;
 - (NSRect) firstRectForCharacterRange: (NSRange)theRange;
 - (void) insertText: (id)aString;
