@@ -37,16 +37,32 @@
 
 @class NSEvent;
 
-typedef enum _NSScrollArrowPosition {
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+enum {
+  NSScrollerStyleLegacy = 0,
+  NSScrollerStyleOverlay = 1
+};
+typedef NSInteger NSScrollerStyle;
+
+enum {
+  NSScrollerKnobStyleDefault = 0,
+  NSScrollerKnobStyleDark = 1,
+  NSScrollerKnobStyleLight = 2
+};
+typedef NSInteger NSScrollerKnobStyle;
+#endif
+
+enum _NSScrollArrowPosition {
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_1, GS_API_LATEST)
   NSScrollerArrowsDefaultSetting = 0,
 #endif
   NSScrollerArrowsMaxEnd = 0,
   NSScrollerArrowsMinEnd,
   NSScrollerArrowsNone 
-} NSScrollArrowPosition;
+};
+typedef NSUInteger NSScrollArrowPosition;
 
-typedef enum _NSScrollerPart {
+enum _NSScrollerPart {
   NSScrollerNoPart = 0,
   NSScrollerDecrementPage,
   NSScrollerKnob,
@@ -54,18 +70,21 @@ typedef enum _NSScrollerPart {
   NSScrollerDecrementLine,
   NSScrollerIncrementLine,
   NSScrollerKnobSlot
-} NSScrollerPart;
+};
+typedef NSUInteger NSScrollerPart;
 
-typedef enum _NSScrollerUsablePart {
+enum _NSScrollerUsablePart {
   NSNoScrollerParts = 0,
   NSOnlyScrollerArrows,
   NSAllScrollerParts  
-} NSUsableScrollerParts;
+};
+typedef NSUInteger NSUsableScrollerParts;
 
-typedef enum _NSScrollerArrow {
+enum _NSScrollerArrow {
   NSScrollerIncrementArrow = 0,
   NSScrollerDecrementArrow
-} NSScrollerArrow;
+};
+typedef NSUInteger NSScrollerArrow;
 
 @interface NSScroller : NSControl <NSCoding>
 {
@@ -86,6 +105,10 @@ typedef enum _NSScrollerArrow {
   } _scFlags;
 }
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
++ (NSScrollerStyle)preferredScrollerStyle;
+#endif
+
 //
 // Laying out the NSScroller 
 //
@@ -140,4 +163,6 @@ typedef enum _NSScrollerArrow {
 
 @end
 
+APPKIT_EXPORT NSString *NSPreferredScrollerStyleDidChangeNotification;
+
 #endif // _GNUstep_H_NSScroller
