@@ -577,32 +577,64 @@ static NSString         *disabledName = @".GNUstepDisabled";
 {
   id	del = [NSApp delegate];
   BOOL	result = NO;
+  NSError *err = nil;
 
   if ([del respondsToSelector: _cmd])
     {
       result = [del application: theApp openFile: file];
     }
   else if ([[NSDocumentController sharedDocumentController]
-    openDocumentWithContentsOfFile: file display: YES] != nil)
+             openDocumentWithContentsOfURL: [NSURL fileURLWithPath: file]
+                                   display: YES
+                                     error: &err] != nil)
     {
       [NSApp activateIgnoringOtherApps: YES];
       result = YES;
     }
+  else
+    {
+      [NSApp presentError: err];
+    }
   return result;
 }
 
+- (void) application: (NSApplication*)theApp
+           openFiles: (NSArray*)files
+{
+  id    del = [NSApp delegate];
+  
+  if ([del respondsToSelector: _cmd])
+    {
+      [del application: theApp openFiles: files];
+    }
+  else
+    {
+      NSString *filePath;
+      NSEnumerator *en = [files objectEnumerator];
+
+      while ((filePath = (NSString *)[en nextObject]) != nil)
+	{
+	  [self application: theApp openFile: filePath];
+	}
+    }
+}
+
+
 - (BOOL) application: (NSApplication*)theApp
    openFileWithoutUI: (NSString*)file
 {
   id	del = [NSApp delegate];
   BOOL	result = NO;
+  NSError *err = nil;
 
   if ([del respondsToSelector: _cmd])
     {
       result = [del application: theApp openFileWithoutUI: file];
     }
   else if ([[NSDocumentController sharedDocumentController]
-    openDocumentWithContentsOfFile: file display: NO] != nil)
+             openDocumentWithContentsOfURL: [NSURL fileURLWithPath: file]
+                                   display: NO
+                                     error: &err] != nil)
     {
       result = YES;
     }
@@ -624,13 +656,16 @@ static NSString         *disabledName = @".GNUstepDisabled";
 {
   id	del = [NSApp delegate];
   BOOL	result = NO;
+  NSError *err = nil;
 
   if ([del respondsToSelector: _cmd])
     {
       result = [del application: theApp openURL: aURL];
     }
   else if ([[NSDocumentController sharedDocumentController]
-    openDocumentWithContentsOfURL: aURL display: YES] != nil)
+             openDocumentWithContentsOfURL: aURL
+                                   display: YES
+                                     error: &err] != nil)
     {
       [NSApp activateIgnoringOtherApps: YES];
       result = YES;
