@@ -29,7 +29,7 @@
 #ifndef _NSBitmapImageRep_PNM_H_include
 #define _NSBitmapImageRep_PNM_H_include
 
-#include "AppKit/NSBitmapImageRep.h"
+#import "AppKit/NSBitmapImageRep.h"
 
 @interface NSBitmapImageRep (PNM)
 
