@@ -29,6 +29,7 @@
 */
 
 #import <Foundation/NSArray.h>
+#import <Foundation/NSDebug.h>
 #import <Foundation/NSDictionary.h>
 #import <Foundation/NSEnumerator.h>
 #import <Foundation/NSException.h>
@@ -43,6 +44,7 @@
 
 #import "AppKit/NSKeyValueBinding.h"
 #import "GSBindingHelpers.h"
+#import "GSFastEnumeration.h"
 
 @implementation NSObject (NSKeyValueBindingCreation)
 
@@ -345,7 +347,10 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
 
 - (void) setValueFor: (NSString *)binding 
 {
-  [src setValue: [self destinationValue] forKey: binding];
+  id value = [self destinationValue];
+
+  NSDebugLLog(@"NSBinding", @"setValueFor: binding %@, source %@ value %@", binding, src, value);
+  [src setValue: value forKey: binding];
 }
 
 - (void) reverseSetValue: (id)value
@@ -355,6 +360,7 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
 
   keyPath = [info objectForKey: NSObservedKeyPathKey];
   dest = [info objectForKey: NSObservedObjectKey];
+  NSDebugLLog(@"NSBinding", @"reverseSetValue: keyPath %@, dest %@ value %@", keyPath, dest, value);
   [dest setValue: value forKeyPath: keyPath];
 }
 
@@ -377,6 +383,7 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
       options = [info objectForKey: NSOptionsKey];
       newValue = [change objectForKey: NSKeyValueChangeNewKey];
       newValue = [self transformValue: newValue withOptions: options];
+      NSDebugLLog(@"NSBinding", @"observeValueForKeyPath: binding %@, keyPath %@, source %@ value %@", binding, keyPath, src, newValue);
       [src setValue: newValue forKey: binding];
     }
 }
@@ -444,7 +451,21 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
 
   if (valueTransformer != nil)
     {
-      value = [valueTransformer transformedValue: value];
+      if ([value isKindOfClass: [NSArray class]])
+        {
+          NSArray *oldValue = (NSArray *)value;
+          NSMutableArray *newValue = [[NSMutableArray alloc] initWithCapacity: [oldValue count]];
+          id<NSFastEnumeration> enumerator = oldValue;
+
+          FOR_IN (id, obj, enumerator)
+            [newValue addObject: [valueTransformer transformedValue: obj]];
+          END_FOR_IN(enumerator)
+          value = AUTORELEASE(newValue);
+        }
+      else
+        {
+          value = [valueTransformer transformedValue: value];
+        }
     }
 
   return value;
@@ -477,6 +498,12 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
   return value;
 }
 
+- (NSString*) description
+{
+  return [NSString stringWithFormat: 
+                     @"GSKeyValueBinding src (%@) info %@", src, info];
+}
+
 @end
 
 @implementation GSKeyValueOrBinding : GSKeyValueBinding 
