@@ -470,8 +470,10 @@ static BOOL menuBarVisible = YES;
 
   if (_menu.horizontal == YES)
     {
-      origin = NSMakePoint (0, [[NSScreen mainScreen] frame].size.height
-	- [_aWindow frame].size.height);
+      NSRect screenFrame = [[NSScreen mainScreen] frame];
+      origin = NSMakePoint (0, screenFrame.size.height
+                            - [_aWindow frame].size.height);
+      origin.y += screenFrame.origin.y;
       [_aWindow setFrameOrigin: origin];
       [_bWindow setFrameOrigin: origin];
     }
@@ -1801,6 +1803,23 @@ static BOOL menuBarVisible = YES;
           [[supermenu menuRepresentation] setHighlightedItemIndex: -1];
           supermenu->_attachedMenu = nil;
         }
+      [nc addObserver: self
+             selector: @selector(windowDidChangeScreen:)
+                 name: NSWindowDidBecomeKeyNotification
+               object: nil];
+      [nc addObserver: self
+             selector: @selector(windowDidChangeScreen:)
+                 name: NSWindowDidChangeScreenNotification
+               object: nil];
+    }
+  else
+    {
+      [nc removeObserver: self
+                    name: NSWindowDidBecomeKeyNotification
+                  object: nil];
+      [nc removeObserver: self
+                    name: NSWindowDidChangeScreenNotification
+                  object: nil];
     }
   [_view update];
 }
@@ -1848,6 +1867,18 @@ static BOOL menuBarVisible = YES;
       [[GSTheme theme] updateAllWindowsWithMenu: [NSApp mainMenu]];
     }
   [self _showTornOffMenuIfAny: notification];
+
+  if ([NSApp mainMenu] == self)
+    {
+      [nc addObserver: self
+             selector: @selector(windowDidChangeScreen:)
+                 name: NSWindowDidBecomeKeyNotification
+               object: nil];
+      [nc addObserver: self
+             selector: @selector(windowDidChangeScreen:)
+                 name: NSWindowDidChangeScreenNotification
+               object: nil];
+    }
 }
 
 - (void) _showOnActivateApp: (NSNotification*)notification
@@ -1860,6 +1891,38 @@ static BOOL menuBarVisible = YES;
   }
 }
 
+- (void) windowDidChangeScreen: (NSNotification*)notification
+{
+  NSWindow *window = [notification object];
+  NSRect   frame;
+  NSRect   oldScreenFrame;
+  NSRect   newScreenFrame;
+  CGFloat  yOffset;
+
+  if ([window isKindOfClass: [NSPanel class]]
+      || window == _aWindow
+      || [window isKeyWindow] == NO
+      || [_aWindow screen] == [window screen]
+      || [_aWindow isVisible] == NO)
+    {
+      return;
+    }
+
+  oldScreenFrame = [[_aWindow screen] frame];
+  newScreenFrame = [[window screen] frame];
+  frame = [_aWindow frame];
+  
+  // Keep left offset fixed
+  frame.origin.x += newScreenFrame.origin.x - oldScreenFrame.origin.x;
+
+  // Keep top offset fixed
+  yOffset = NSMaxY(oldScreenFrame) - NSMaxY(frame);
+  frame.origin.y = NSMaxY(newScreenFrame) - yOffset - frame.size.height;
+  
+  // setFrame: changes _screen value.
+  [self nestedSetFrameOrigin: frame.origin];
+}
+
 - (BOOL) isTransient
 {
   return _menu.transient;
