@@ -63,12 +63,15 @@
 */  
 
 #import <Foundation/NSDictionary.h>
+#import <Foundation/NSKeyValueCoding.h>
 #import <Foundation/NSNotification.h>
 #import <Foundation/NSValue.h>
 #import <Foundation/NSSortDescriptor.h>
+#import "AppKit/NSKeyValueBinding.h"
 #import "AppKit/NSTableHeaderCell.h"
 #import "AppKit/NSTableColumn.h"
 #import "AppKit/NSTableView.h"
+#import "GSBindingHelpers.h"
 
 /**
   <p>
@@ -85,7 +88,11 @@
 + (void) initialize
 {
   if (self == [NSTableColumn class])
-    [self setVersion: 3];
+    {
+      [self setVersion: 3];
+      [self exposeBinding: NSValueBinding];
+      [self exposeBinding: NSEnabledBinding];
+    }
 }
 
 /*
@@ -127,11 +134,14 @@
 
 - (void) dealloc
 {
-  RELEASE (_headerCell);
-  RELEASE (_headerToolTip);
-  RELEASE (_dataCell);
-  RELEASE (_sortDescriptorPrototype);
-  TEST_RELEASE (_identifier);
+  // Remove all key value bindings for this view.
+  [GSKeyValueBinding unbindAllForObject: self];
+
+  RELEASE(_headerCell);
+  RELEASE(_headerToolTip);
+  RELEASE(_dataCell);
+  RELEASE(_sortDescriptorPrototype);
+  TEST_RELEASE(_identifier);
   [super dealloc];
 }
 
@@ -192,9 +202,9 @@
   is redisplayed (by calling tile), and the
   NSTableViewColumnDidResizeNotification is posted on behalf of the
   table view.  */
-- (void) setWidth: (float)newWidth
+- (void) setWidth: (CGFloat)newWidth
 {
-  float oldWidth = _width;
+  CGFloat oldWidth = _width;
 
   if (newWidth > _max_width)
     newWidth = _max_width;
@@ -223,7 +233,7 @@
 
 /** Return the width of the table column. The 
     default width is 100. */
-- (float) width
+- (CGFloat) width
 {
   return _width;
 }
@@ -232,7 +242,7 @@
   Set the min width of the table column, eventually adjusting the
   width of the column if it is smaller than the new min width.  In no
   way a table column can be made smaller than its min width.  */
-- (void) setMinWidth: (float)minWidth
+- (void) setMinWidth: (CGFloat)minWidth
 {
   _min_width = minWidth;
   if (_width < _min_width)
@@ -243,7 +253,7 @@
   Return the column's min width.  The column can in no way be resized
   to a width smaller than this min width.  The default min width is
   10.  */
-- (float) minWidth
+- (CGFloat) minWidth
 {
   return _min_width;
 }
@@ -252,7 +262,7 @@
   Set the max width of the table column, eventually adjusting the
   width of the column if it is bigger than the new max width.  In no
   way a table column can be made bigger than its max width.  */
-- (void) setMaxWidth: (float)maxWidth
+- (void) setMaxWidth: (CGFloat)maxWidth
 {
   _max_width = maxWidth;
   if (_width > _max_width)
@@ -263,7 +273,7 @@
   Return the column's max width.  The column can in no way be resized
   to a width bigger than this max width.  The default max width is
   100000.  */
-- (float) maxWidth
+- (CGFloat) maxWidth
 {
   return _max_width;
 }
@@ -319,7 +329,7 @@ it resizes. */
   smaller than the column header width, it is increased to it).  */
 - (void) sizeToFit
 {
-  float new_width;
+  CGFloat new_width;
 
   new_width = [_headerCell cellSize].width;
 
@@ -433,7 +443,7 @@ Return the toop tip text displayed when the pointer is in the header area. */
   return _dataCell;
 }
 
-- (NSCell*) dataCellForRow: (int)row
+- (NSCell*) dataCellForRow: (NSInteger)row
 {
   return [self dataCell];
 }
@@ -525,6 +535,10 @@ to YES. */
         {
           [self setEditable: [aDecoder decodeBoolForKey: @"NSIsEditable"]];
         }
+      else
+        {
+          [self setEditable: NO];
+        }
       if ([aDecoder containsValueForKey: @"NSWidth"])
         {
           [self setWidth: [aDecoder decodeFloatForKey: @"NSWidth"]]; 
@@ -599,4 +613,37 @@ to YES. */
   return self;
 }
 
+- (void) setValue: (id)anObject forKey: (NSString*)aKey
+{
+  if ([aKey isEqual: NSValueBinding])
+    {
+      // FIXME
+      // Reload data
+    }
+  else if ([aKey isEqual: NSEnabledBinding])
+    {
+      // FIXME
+    }
+  else
+    {
+      [super setValue: anObject forKey: aKey];
+    }
+}
+
+- (id) valueForKey: (NSString*)aKey
+{
+  if ([aKey isEqual: NSValueBinding])
+    {
+      return nil;
+    }
+  else if ([aKey isEqual: NSEnabledBinding])
+    {
+      // FIXME
+      return [NSNumber numberWithBool: YES];
+    }
+  else
+    {
+      return [super valueForKey: aKey];
+    }
+}
 @end
