@@ -28,17 +28,18 @@
    Boston, MA 02110-1301, USA.
 */ 
 
-#include "config.h"
-#include <Foundation/NSNotification.h>
-#include "AppKit/NSAttributedString.h"
-#include "AppKit/NSColor.h"
-#include "AppKit/NSControl.h"
-#include "AppKit/NSEvent.h"
-#include "AppKit/NSFont.h"
-#include "AppKit/NSGraphics.h"
-#include "AppKit/NSTextField.h"
-#include "AppKit/NSTextFieldCell.h"
-#include "AppKit/NSText.h"
+#import "config.h"
+#import <Foundation/NSNotification.h>
+#import "AppKit/NSAttributedString.h"
+#import "AppKit/NSColor.h"
+#import "AppKit/NSControl.h"
+#import "AppKit/NSEvent.h"
+#import "AppKit/NSFont.h"
+#import "AppKit/NSGraphics.h"
+#import "AppKit/NSStringDrawing.h"
+#import "AppKit/NSTextField.h"
+#import "AppKit/NSTextFieldCell.h"
+#import "AppKit/NSText.h"
 
 @implementation NSTextFieldCell
 
@@ -202,13 +203,13 @@
                            inView: (NSView*)controlView
 {
   if (_textfieldcell_draws_background)
-	  {
+    {
       if ([self isEnabled])
-	      {
+        {
           [_background_color set];
         }
       else
-	      {
+        {
           [[NSColor controlBackgroundColor] set];
         }
       NSRectFill([self drawingRectForBounds: cellFrame]);
@@ -223,10 +224,28 @@
   [self _drawBackgroundWithFrame: cellFrame inView: controlView];
 }
 
+- (void) drawInteriorWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
+{
+  if (_cell.in_editing)
+    [self _drawEditorWithFrame: cellFrame inView: controlView];
+  else
+    {
+      NSRect titleRect;
+
+      /* Make sure we are a text cell; titleRect might return an incorrect
+         rectangle otherwise. Note that the type could be different if the
+         user has set an image on us, which we just ignore (OS X does so as
+         well). */
+      _cell.type = NSTextCellType;
+      titleRect = [self titleRectForBounds: cellFrame];
+      [[self _drawAttributedString] drawInRect: titleRect];
+    }
+}
+
 /* 
    Attributed string that will be displayed.
  */
-- (NSAttributedString*)_drawAttributedString
+- (NSAttributedString*) _drawAttributedString
 {
   NSAttributedString *attrStr;
 
