@@ -34,19 +34,22 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#if	defined(HAVE_GETMNTINFO)
+
+#if defined(HAVE_GETMNTINFO)
 #include <sys/param.h>
 #include <sys/mount.h>
-#elif	defined(HAVE_GETMNTENT) && defined (MNT_MEMB)
-#if	defined(HAVE_MNTENT_H)
-#include <mntent.h>
-#elif defined(HAVE_SYS_MNTENT_H)
-#include <sys/mntent.h>
-#else
-#undef	HAVE_GETMNTENT
-#endif
 #endif
 
+#if defined(HAVE_GETMNTENT) && defined (MNT_MEMB)
+  #if defined(HAVE_MNTENT_H)
+  #include <mntent.h>
+  #elif defined(HAVE_SYS_MNTENT_H)
+  #include <sys/mntent.h>
+  #else
+  #undef HAVE_GETMNTENT
+  #endif
+#endif /* HAVE_GETMNTENT */
+
 #if defined (HAVE_SYS_STATVFS_H)
 #include <sys/statvfs.h>
 #endif
@@ -1305,7 +1308,6 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
      non-standard f_basetype field, which provides the name of the
      underlying file system type.
   */
-  uid_t uid;
   BOOL isRootFS;
   BOOL hasOwnership;
 
@@ -1320,7 +1322,6 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
   if (statfs([fullPath fileSystemRepresentation], &m))
     return NO;  
 #endif
-  uid = geteuid();
 
   *writableFlag = 1;
 #if  defined(HAVE_STRUCT_STATVFS_F_FLAG)
@@ -1339,9 +1340,11 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
 
   hasOwnership = NO;
 #if (defined(USING_STATFS) && defined(HAVE_STRUCT_STATFS_F_OWNER)) || (defined(USING_STATVFS) &&  defined(HAVE_STRUCT_STATVFS_F_OWNER))
+  uid_t uid = geteuid();
   if (uid == 0 || uid == m.f_owner)
     hasOwnership = YES;
 #elif (defined(USING_STATVFS) && !defined(USING_STATFS) && defined (HAVE_STATFS) && defined(HAVE_STRUCT_STATFS_F_OWNER))
+  uid_t uid = geteuid();
   // FreeBSD only?
   struct statfs m2;
   statfs([fullPath fileSystemRepresentation], &m2);
