@@ -29,8 +29,12 @@
 
 #import "config.h"
 #import <Foundation/NSString.h>
+#import <Foundation/NSObjCRuntime.h>
+
 #import "AppKit/NSApplication.h"
 #import "AppKit/NSEvent.h"
+#import "AppKit/NSAppearance.h"
+#import "AppKit/NSFontCollection.h"
 
 // Global strings
 NSString *NSModalPanelRunLoopMode = @"NSModalPanelRunLoopMode";
@@ -41,43 +45,43 @@ const double NSAppKitVersionNumber = NSAppKitVersionNumber10_4;
 //
 // Global Exception Strings
 //
-NSString *NSAbortModalException = @"NSAbortModalException";
-NSString *NSAbortPrintingException = @"NSAbortPrintingException";
-NSString *NSAppKitIgnoredException = @"NSAppKitIgnoredException";
-NSString *NSAppKitVirtualMemoryException = @"NSAppKitVirtualMemoryException";
-NSString *NSBadBitmapParametersException = @"NSBadBitmapParametersException";
-NSString *NSBadComparisonException = @"NSBadComparisonException";
-NSString *NSBadRTFColorTableException = @"NSBadRTFColorTableException";
-NSString *NSBadRTFDirectiveException = @"NSBadRTFDirectiveException";
-NSString *NSBadRTFFontTableException = @"NSBadRTFFontTableException";
-NSString *NSBadRTFStyleSheetException = @"NSBadRTFStyleSheetException";
-NSString *NSBrowserIllegalDelegateException = @"NSBrowserIllegalDelegateException";
-NSString *NSColorListIOException = @"NSColorListIOException";
-NSString *NSColorListNotEditableException = @"NSColorListNotEditableException";
-NSString *NSDraggingException = @"NSDraggingException";
-NSString *NSFontUnavailableException = @"NSFontUnavailableException";
-NSString *NSIllegalSelectorException = @"NSIllegalSelectorException";
-NSString *NSImageCacheException = @"NSImageCacheException";
-NSString *NSNibLoadingException = @"NSNibLoadingException";
-NSString *NSPPDIncludeNotFoundException = @"NSPPDIncludeNotFoundException";
-NSString *NSPPDIncludeStackOverflowException = @"NSPPDIncludeStackOverflowException";
-NSString *NSPPDIncludeStackUnderflowException = @"NSPPDIncludeStackUnderflowException";
-NSString *NSPPDParseException = @"NSPPDParseException";
-NSString *NSPrintOperationExistsException = @"NSPrintOperationExistsException";
-NSString *NSPrintPackageException = @"NSPrintPackageException";
-NSString *NSPrintingCommunicationException = @"NSPrintingCommunicationException";
-NSString *NSRTFPropertyStackOverflowException = @"NSRTFPropertyStackOverflowException";
-NSString *NSTIFFException = @"NSTIFFException";
-NSString *NSTextLineTooLongException = @"NSTextLineTooLongException";
-NSString *NSTextNoSelectionException = @"NSTextNoSelectionException";
-NSString *NSTextReadException = @"NSTextReadException";
-NSString *NSTextWriteException = @"NSTextWriteException";
-NSString *NSTypedStreamVersionException = @"NSTypedStreamVersionException";
-NSString *NSWindowServerCommunicationException = @"NSWindowServerCommunicationException";
-NSString *NSWordTablesReadException = @"NSWordTablesReadException";
-NSString *NSWordTablesWriteException = @"NSWordTablesWriteException";
+NSExceptionName NSAbortModalException = @"NSAbortModalException";
+NSExceptionName NSAbortPrintingException = @"NSAbortPrintingException";
+NSExceptionName NSAppKitIgnoredException = @"NSAppKitIgnoredException";
+NSExceptionName NSAppKitVirtualMemoryException = @"NSAppKitVirtualMemoryException";
+NSExceptionName NSBadBitmapParametersException = @"NSBadBitmapParametersException";
+NSExceptionName NSBadComparisonException = @"NSBadComparisonException";
+NSExceptionName NSBadRTFColorTableException = @"NSBadRTFColorTableException";
+NSExceptionName NSBadRTFDirectiveException = @"NSBadRTFDirectiveException";
+NSExceptionName NSBadRTFFontTableException = @"NSBadRTFFontTableException";
+NSExceptionName NSBadRTFStyleSheetException = @"NSBadRTFStyleSheetException";
+NSExceptionName NSBrowserIllegalDelegateException = @"NSBrowserIllegalDelegateException";
+NSExceptionName NSColorListIOException = @"NSColorListIOException";
+NSExceptionName NSColorListNotEditableException = @"NSColorListNotEditableException";
+NSExceptionName NSDraggingException = @"NSDraggingException";
+NSExceptionName NSFontUnavailableException = @"NSFontUnavailableException";
+NSExceptionName NSIllegalSelectorException = @"NSIllegalSelectorException";
+NSExceptionName NSImageCacheException = @"NSImageCacheException";
+NSExceptionName NSNibLoadingException = @"NSNibLoadingException";
+NSExceptionName NSPPDIncludeNotFoundException = @"NSPPDIncludeNotFoundException";
+NSExceptionName NSPPDIncludeStackOverflowException = @"NSPPDIncludeStackOverflowException";
+NSExceptionName NSPPDIncludeStackUnderflowException = @"NSPPDIncludeStackUnderflowException";
+NSExceptionName NSPPDParseException = @"NSPPDParseException";
+NSExceptionName NSPrintOperationExistsException = @"NSPrintOperationExistsException";
+NSExceptionName NSPrintPackageException = @"NSPrintPackageException";
+NSExceptionName NSPrintingCommunicationException = @"NSPrintingCommunicationException";
+NSExceptionName NSRTFPropertyStackOverflowException = @"NSRTFPropertyStackOverflowException";
+NSExceptionName NSTIFFException = @"NSTIFFException";
+NSExceptionName NSTextLineTooLongException = @"NSTextLineTooLongException";
+NSExceptionName NSTextNoSelectionException = @"NSTextNoSelectionException";
+NSExceptionName NSTextReadException = @"NSTextReadException";
+NSExceptionName NSTextWriteException = @"NSTextWriteException";
+NSExceptionName NSTypedStreamVersionException = @"NSTypedStreamVersionException";
+NSExceptionName NSWindowServerCommunicationException = @"NSWindowServerCommunicationException";
+NSExceptionName NSWordTablesReadException = @"NSWordTablesReadException";
+NSExceptionName NSWordTablesWriteException = @"NSWordTablesWriteException";
 
-NSString *GSWindowServerInternalException = @"WindowServerInternal";
+NSExceptionName GSWindowServerInternalException = @"WindowServerInternal";
 
 // NSAnimation
 NSString* NSAnimationProgressMarkNotification
@@ -760,7 +764,9 @@ NSString *NSHiddenBinding = @"hidden";
 NSString *NSSelectedIndexBinding = @"selectedIndex";
 NSString *NSSelectedObjectBinding = @"selectedObject";
 NSString *NSSelectedTagBinding = @"selectedTag";
+NSString *NSSelectedValueBinding = @"selectedValue";
 NSString *NSSelectionIndexesBinding = @"selectionIndexes";
+NSString *NSSortDescriptorsBinding = @"sortDescriptors";
 NSString *NSTextColorBinding = @"textColor";
 NSString *NSTitleBinding = @"title";
 NSString *NSToolTipBinding = @"toolTip";
@@ -785,6 +791,49 @@ NSString *NSImageNameFontPanel = @"NSFontPanel";
 NSString *NSImageNameColorPanel = @"NSColorPanel";
 NSString *NSImageNameCaution = @"NSCaution";
 
+// NSRuleEditor
+NSString *const NSRuleEditorPredicateLeftExpression = @"NSRuleEditorPredicateLeftExpression";
+NSString *const NSRuleEditorPredicateRightExpression = @"NSRuleEditorPredicateRightExpression";
+NSString *const NSRuleEditorPredicateComparisonModifier = @"NSRuleEditorPredicateComparisonModifier";
+NSString *const NSRuleEditorPredicateOptions = @"NSRuleEditorPredicateOptions";
+NSString *const NSRuleEditorPredicateOperatorType = @"NSRuleEditorPredicateOperatorType";
+NSString *const NSRuleEditorPredicateCustomSelector = @"NSRuleEditorPredicateCustomSelector";
+NSString *const NSRuleEditorPredicateCompoundType = @"NSRuleEditorPredicateCompoundType";
+
+NSString *NSRuleEditorRowsDidChangeNotification = @"NSRuleEditorRowsDidChangeNotification";
+
+// NSAppearance
+const NSAppearanceName NSAppearanceNameAqua = @"NSAppearanceNameAqua";
+const NSAppearanceName NSAppearanceNameDarkAqua = @"NSAppearanceNameDarkAqua";
+const NSAppearanceName NSAppearanceNameVibrantLight = @"NSAppearanceNameVibrantLight";
+const NSAppearanceName NSAppearanceNameVibrantDark = @"NSAppearanceNameVibrantDark";
+const NSAppearanceName NSAppearanceNameAccessibilityHighContrastAqua = @"NSAppearanceNameAccessibilityHighContrastAqua";
+const NSAppearanceName NSAppearanceNameAccessibilityHighContrastDarkAqua = @"NSAppearanceNameAccessibilityHighContrastDarkAqua";
+const NSAppearanceName NSAppearanceNameAccessibilityHighContrastVibrantLight =
+  @"NSAppearanceNameAccessibilityHighContrastVibrantLight";
+const NSAppearanceName NSAppearanceNameAccessibilityHighContrastVibrantDark =
+  @"NSAppearanceNameAccessibilityHighContrastVibrantDark";
+const NSAppearanceName NSAppearanceNameLightContent = @"NSAppearanceNameLightContent";
+
+// Values for NSFontCollectionAction
+NSFontCollectionActionTypeKey const NSFontCollectionWasShown = @"NSFontCollectionWasShown";
+NSFontCollectionActionTypeKey const NSFontCollectionWasHidden = @"NSFontCollectionWasHidden";
+NSFontCollectionActionTypeKey const NSFontCollectionWasRenamed = @"NSFontCollectionWasRenamed";
+
+// Standard named collections
+NSFontCollectionName const NSFontCollectionAllFonts = @"NSFontCollectionAllFonts";
+NSFontCollectionName const NSFontCollectionUser = @"NSFontCollectionUser";
+NSFontCollectionName const NSFontCollectionFavorites = @"NSFontCollectionFavorites";
+NSFontCollectionName const NSFontCollectionRecentlyUsed = @"NSFontCollectionRecentlyUsed";
+
+// Collections
+NSFontCollectionMatchingOptionKey const NSFontCollectionIncludeDisabledFontsOption = @"NSFontCollectionIncludeDisabledFontsOption";
+NSFontCollectionMatchingOptionKey const NSFontCollectionRemoveDuplicatesOption = @"NSFontCollectionRemoveDuplicatesOption";
+NSFontCollectionMatchingOptionKey const NSFontCollectionDisallowAutoActivationOption = @"NSFontCollectionDisallowAutoActivationOption";
+
+// Speech recognition...
+const NSString *GSSpeechRecognizerDidRecognizeWordNotification = @"GSSpeechRecognizerDidRecognizeWordNotification"; 
+
 extern void __objc_gui_force_linking (void);
 
 void
@@ -793,5 +842,3 @@ __objc_gui_force_linking (void)
   extern void __objc_gui_linking (void);
   __objc_gui_linking ();
 }
-
-
